@@ -24,7 +24,7 @@
 # Written by Peter J Billam, http://www.pjb.com.au
 
 package Crypt::Tea;
-$VERSION = '2.06';
+$VERSION = '2.07';
 
 # Don't like depending on externals; this is strong encrytion ... but ...
 use Exporter; @ISA = qw(Exporter);
@@ -344,7 +344,7 @@ function blocks2bytes(blocks) {
  return bytes;
 }
 function digest_pad (bytearray) {
- // add 1 char ('0'..'15') at front to specify no of \0 pad chars at end
+ // add 1 char ('0'..'15') at front to specify no of \x00 pad chars at end
  var newarray = new Array();  var ina = 0;
  var iba = 0; var nba = bytearray.length;
  var npads = 15 - (nba % 16); newarray[ina] = npads; ina++;
@@ -485,70 +485,70 @@ function tea_decode (v, k) {
 
 // ------------- assocarys used by the conversion routines -----------
 c2b = new Object();
-c2b["\000"]=0;  c2b["\001"]=1;  c2b["\002"]=2;  c2b["\003"]=3;
-c2b["\004"]=4;  c2b["\005"]=5;  c2b["\006"]=6;  c2b["\007"]=7;
-c2b["\010"]=8;  c2b["\011"]=9;  c2b["\012"]=10; c2b["\013"]=11;
-c2b["\014"]=12; c2b["\015"]=13; c2b["\016"]=14; c2b["\017"]=15;
-c2b["\020"]=16; c2b["\021"]=17; c2b["\022"]=18; c2b["\023"]=19;
-c2b["\024"]=20; c2b["\025"]=21; c2b["\026"]=22; c2b["\027"]=23;
-c2b["\030"]=24; c2b["\031"]=25; c2b["\032"]=26; c2b["\033"]=27;
-c2b["\034"]=28; c2b["\035"]=29; c2b["\036"]=30; c2b["\037"]=31;
-c2b["\040"]=32; c2b["\041"]=33; c2b["\042"]=34; c2b["\043"]=35;
-c2b["\044"]=36; c2b["\045"]=37; c2b["\046"]=38; c2b["\047"]=39;
-c2b["\050"]=40; c2b["\051"]=41; c2b["\052"]=42; c2b["\053"]=43;
-c2b["\054"]=44; c2b["\055"]=45; c2b["\056"]=46; c2b["\057"]=47;
-c2b["\060"]=48; c2b["\061"]=49; c2b["\062"]=50; c2b["\063"]=51;
-c2b["\064"]=52; c2b["\065"]=53; c2b["\066"]=54; c2b["\067"]=55;
-c2b["\070"]=56; c2b["\071"]=57; c2b["\072"]=58; c2b["\073"]=59;
-c2b["\074"]=60; c2b["\075"]=61; c2b["\076"]=62; c2b["\077"]=63;
-c2b["\100"]=64; c2b["\101"]=65; c2b["\102"]=66; c2b["\103"]=67;
-c2b["\104"]=68; c2b["\105"]=69; c2b["\106"]=70; c2b["\107"]=71;
-c2b["\110"]=72; c2b["\111"]=73; c2b["\112"]=74; c2b["\113"]=75;
-c2b["\114"]=76; c2b["\115"]=77; c2b["\116"]=78; c2b["\117"]=79;
-c2b["\120"]=80; c2b["\121"]=81; c2b["\122"]=82; c2b["\123"]=83;
-c2b["\124"]=84; c2b["\125"]=85; c2b["\126"]=86; c2b["\127"]=87;
-c2b["\130"]=88; c2b["\131"]=89; c2b["\132"]=90; c2b["\133"]=91;
-c2b["\134"]=92; c2b["\135"]=93; c2b["\136"]=94; c2b["\137"]=95;
-c2b["\140"]=96; c2b["\141"]=97; c2b["\142"]=98; c2b["\143"]=99;
-c2b["\144"]=100; c2b["\145"]=101; c2b["\146"]=102; c2b["\147"]=103;
-c2b["\150"]=104; c2b["\151"]=105; c2b["\152"]=106; c2b["\153"]=107;
-c2b["\154"]=108; c2b["\155"]=109; c2b["\156"]=110; c2b["\157"]=111;
-c2b["\160"]=112; c2b["\161"]=113; c2b["\162"]=114; c2b["\163"]=115;
-c2b["\164"]=116; c2b["\165"]=117; c2b["\166"]=118; c2b["\167"]=119;
-c2b["\170"]=120; c2b["\171"]=121; c2b["\172"]=122; c2b["\173"]=123;
-c2b["\174"]=124; c2b["\175"]=125; c2b["\176"]=126; c2b["\177"]=127;
-c2b["\200"]=128; c2b["\201"]=129; c2b["\202"]=130; c2b["\203"]=131;
-c2b["\204"]=132; c2b["\205"]=133; c2b["\206"]=134; c2b["\207"]=135;
-c2b["\210"]=136; c2b["\211"]=137; c2b["\212"]=138; c2b["\213"]=139;
-c2b["\214"]=140; c2b["\215"]=141; c2b["\216"]=142; c2b["\217"]=143;
-c2b["\220"]=144; c2b["\221"]=145; c2b["\222"]=146; c2b["\223"]=147;
-c2b["\224"]=148; c2b["\225"]=149; c2b["\226"]=150; c2b["\227"]=151;
-c2b["\230"]=152; c2b["\231"]=153; c2b["\232"]=154; c2b["\233"]=155;
-c2b["\234"]=156; c2b["\235"]=157; c2b["\236"]=158; c2b["\237"]=159;
-c2b["\240"]=160; c2b["\241"]=161; c2b["\242"]=162; c2b["\243"]=163;
-c2b["\244"]=164; c2b["\245"]=165; c2b["\246"]=166; c2b["\247"]=167;
-c2b["\250"]=168; c2b["\251"]=169; c2b["\252"]=170; c2b["\253"]=171;
-c2b["\254"]=172; c2b["\255"]=173; c2b["\256"]=174; c2b["\257"]=175;
-c2b["\260"]=176; c2b["\261"]=177; c2b["\262"]=178; c2b["\263"]=179;
-c2b["\264"]=180; c2b["\265"]=181; c2b["\266"]=182; c2b["\267"]=183;
-c2b["\270"]=184; c2b["\271"]=185; c2b["\272"]=186; c2b["\273"]=187;
-c2b["\274"]=188; c2b["\275"]=189; c2b["\276"]=190; c2b["\277"]=191;
-c2b["\300"]=192; c2b["\301"]=193; c2b["\302"]=194; c2b["\303"]=195;
-c2b["\304"]=196; c2b["\305"]=197; c2b["\306"]=198; c2b["\307"]=199;
-c2b["\310"]=200; c2b["\311"]=201; c2b["\312"]=202; c2b["\313"]=203;
-c2b["\314"]=204; c2b["\315"]=205; c2b["\316"]=206; c2b["\317"]=207;
-c2b["\320"]=208; c2b["\321"]=209; c2b["\322"]=210; c2b["\323"]=211;
-c2b["\324"]=212; c2b["\325"]=213; c2b["\326"]=214; c2b["\327"]=215;
-c2b["\330"]=216; c2b["\331"]=217; c2b["\332"]=218; c2b["\333"]=219;
-c2b["\334"]=220; c2b["\335"]=221; c2b["\336"]=222; c2b["\337"]=223;
-c2b["\340"]=224; c2b["\341"]=225; c2b["\342"]=226; c2b["\343"]=227;
-c2b["\344"]=228; c2b["\345"]=229; c2b["\346"]=230; c2b["\347"]=231;
-c2b["\350"]=232; c2b["\351"]=233; c2b["\352"]=234; c2b["\353"]=235;
-c2b["\354"]=236; c2b["\355"]=237; c2b["\356"]=238; c2b["\357"]=239;
-c2b["\360"]=240; c2b["\361"]=241; c2b["\362"]=242; c2b["\363"]=243;
-c2b["\364"]=244; c2b["\365"]=245; c2b["\366"]=246; c2b["\367"]=247;
-c2b["\370"]=248; c2b["\371"]=249; c2b["\372"]=250; c2b["\373"]=251;
-c2b["\374"]=252; c2b["\375"]=253; c2b["\376"]=254; c2b["\377"]=255;
+c2b["\x00"]=0;  c2b["\x01"]=1;  c2b["\x02"]=2;  c2b["\x03"]=3;
+c2b["\x04"]=4;  c2b["\x05"]=5;  c2b["\x06"]=6;  c2b["\x07"]=7;
+c2b["\x08"]=8;  c2b["\x09"]=9;  c2b["\x0A"]=10; c2b["\x0B"]=11;
+c2b["\x0C"]=12; c2b["\x0D"]=13; c2b["\x0E"]=14; c2b["\x0F"]=15;
+c2b["\x10"]=16; c2b["\x11"]=17; c2b["\x12"]=18; c2b["\x13"]=19;
+c2b["\x14"]=20; c2b["\x15"]=21; c2b["\x16"]=22; c2b["\x17"]=23;
+c2b["\x18"]=24; c2b["\x19"]=25; c2b["\x1A"]=26; c2b["\x1B"]=27;
+c2b["\x1C"]=28; c2b["\x1D"]=29; c2b["\x1E"]=30; c2b["\x1F"]=31;
+c2b["\x20"]=32; c2b["\x21"]=33; c2b["\x22"]=34; c2b["\x23"]=35;
+c2b["\x24"]=36; c2b["\x25"]=37; c2b["\x26"]=38; c2b["\x27"]=39;
+c2b["\x28"]=40; c2b["\x29"]=41; c2b["\x2A"]=42; c2b["\x2B"]=43;
+c2b["\x2C"]=44; c2b["\x2D"]=45; c2b["\x2E"]=46; c2b["\x2F"]=47;
+c2b["\x30"]=48; c2b["\x31"]=49; c2b["\x32"]=50; c2b["\x33"]=51;
+c2b["\x34"]=52; c2b["\x35"]=53; c2b["\x36"]=54; c2b["\x37"]=55;
+c2b["\x38"]=56; c2b["\x39"]=57; c2b["\x3A"]=58; c2b["\x3B"]=59;
+c2b["\x3C"]=60; c2b["\x3D"]=61; c2b["\x3E"]=62; c2b["\x3F"]=63;
+c2b["\x40"]=64; c2b["\x41"]=65; c2b["\x42"]=66; c2b["\x43"]=67;
+c2b["\x44"]=68; c2b["\x45"]=69; c2b["\x46"]=70; c2b["\x47"]=71;
+c2b["\x48"]=72; c2b["\x49"]=73; c2b["\x4A"]=74; c2b["\x4B"]=75;
+c2b["\x4C"]=76; c2b["\x4D"]=77; c2b["\x4E"]=78; c2b["\x4F"]=79;
+c2b["\x50"]=80; c2b["\x51"]=81; c2b["\x52"]=82; c2b["\x53"]=83;
+c2b["\x54"]=84; c2b["\x55"]=85; c2b["\x56"]=86; c2b["\x57"]=87;
+c2b["\x58"]=88; c2b["\x59"]=89; c2b["\x5A"]=90; c2b["\x5B"]=91;
+c2b["\x5C"]=92; c2b["\x5D"]=93; c2b["\x5E"]=94; c2b["\x5F"]=95;
+c2b["\x60"]=96; c2b["\x61"]=97; c2b["\x62"]=98; c2b["\x63"]=99;
+c2b["\x64"]=100; c2b["\x65"]=101; c2b["\x66"]=102; c2b["\x67"]=103;
+c2b["\x68"]=104; c2b["\x69"]=105; c2b["\x6A"]=106; c2b["\x6B"]=107;
+c2b["\x6C"]=108; c2b["\x6D"]=109; c2b["\x6E"]=110; c2b["\x6F"]=111;
+c2b["\x70"]=112; c2b["\x71"]=113; c2b["\x72"]=114; c2b["\x73"]=115;
+c2b["\x74"]=116; c2b["\x75"]=117; c2b["\x76"]=118; c2b["\x77"]=119;
+c2b["\x78"]=120; c2b["\x79"]=121; c2b["\x7A"]=122; c2b["\x7B"]=123;
+c2b["\x7C"]=124; c2b["\x7D"]=125; c2b["\x7E"]=126; c2b["\x7F"]=127;
+c2b["\x80"]=128; c2b["\x81"]=129; c2b["\x82"]=130; c2b["\x83"]=131;
+c2b["\x84"]=132; c2b["\x85"]=133; c2b["\x86"]=134; c2b["\x87"]=135;
+c2b["\x88"]=136; c2b["\x89"]=137; c2b["\x8A"]=138; c2b["\x8B"]=139;
+c2b["\x8C"]=140; c2b["\x8D"]=141; c2b["\x8E"]=142; c2b["\x8F"]=143;
+c2b["\x90"]=144; c2b["\x91"]=145; c2b["\x92"]=146; c2b["\x93"]=147;
+c2b["\x94"]=148; c2b["\x95"]=149; c2b["\x96"]=150; c2b["\x97"]=151;
+c2b["\x98"]=152; c2b["\x99"]=153; c2b["\x9A"]=154; c2b["\x9B"]=155;
+c2b["\x9C"]=156; c2b["\x9D"]=157; c2b["\x9E"]=158; c2b["\x9F"]=159;
+c2b["\xA0"]=160; c2b["\xA1"]=161; c2b["\xA2"]=162; c2b["\xA3"]=163;
+c2b["\xA4"]=164; c2b["\xA5"]=165; c2b["\xA6"]=166; c2b["\xA7"]=167;
+c2b["\xA8"]=168; c2b["\xA9"]=169; c2b["\xAA"]=170; c2b["\xAB"]=171;
+c2b["\xAC"]=172; c2b["\xAD"]=173; c2b["\xAE"]=174; c2b["\xAF"]=175;
+c2b["\xB0"]=176; c2b["\xB1"]=177; c2b["\xB2"]=178; c2b["\xB3"]=179;
+c2b["\xB4"]=180; c2b["\xB5"]=181; c2b["\xB6"]=182; c2b["\xB7"]=183;
+c2b["\xB8"]=184; c2b["\xB9"]=185; c2b["\xBA"]=186; c2b["\xBB"]=187;
+c2b["\xBC"]=188; c2b["\xBD"]=189; c2b["\xBE"]=190; c2b["\xBF"]=191;
+c2b["\xC0"]=192; c2b["\xC1"]=193; c2b["\xC2"]=194; c2b["\xC3"]=195;
+c2b["\xC4"]=196; c2b["\xC5"]=197; c2b["\xC6"]=198; c2b["\xC7"]=199;
+c2b["\xC8"]=200; c2b["\xC9"]=201; c2b["\xCA"]=202; c2b["\xCB"]=203;
+c2b["\xCC"]=204; c2b["\xCD"]=205; c2b["\xCE"]=206; c2b["\xCF"]=207;
+c2b["\xD0"]=208; c2b["\xD1"]=209; c2b["\xD2"]=210; c2b["\xD3"]=211;
+c2b["\xD4"]=212; c2b["\xD5"]=213; c2b["\xD6"]=214; c2b["\xD7"]=215;
+c2b["\xD8"]=216; c2b["\xD9"]=217; c2b["\xDA"]=218; c2b["\xDB"]=219;
+c2b["\xDC"]=220; c2b["\xDD"]=221; c2b["\xDE"]=222; c2b["\xDF"]=223;
+c2b["\xE0"]=224; c2b["\xE1"]=225; c2b["\xE2"]=226; c2b["\xE3"]=227;
+c2b["\xE4"]=228; c2b["\xE5"]=229; c2b["\xE6"]=230; c2b["\xE7"]=231;
+c2b["\xE8"]=232; c2b["\xE9"]=233; c2b["\xEA"]=234; c2b["\xEB"]=235;
+c2b["\xEC"]=236; c2b["\xED"]=237; c2b["\xEE"]=238; c2b["\xEF"]=239;
+c2b["\xF0"]=240; c2b["\xF1"]=241; c2b["\xF2"]=242; c2b["\xF3"]=243;
+c2b["\xF4"]=244; c2b["\xF5"]=245; c2b["\xF6"]=246; c2b["\xF7"]=247;
+c2b["\xF8"]=248; c2b["\xF9"]=249; c2b["\xFA"]=250; c2b["\xFB"]=251;
+c2b["\xFC"]=252; c2b["\xFD"]=253; c2b["\xFE"]=254; c2b["\xFF"]=255;
 b2c = new Object();
 for (b in c2b) { b2c[c2b[b]] = b; }
 
@@ -612,7 +612,7 @@ and some Modes of Use, in Perl and JavaScript.
 The $key is a sufficiently longish string; at least 17 random 8-bit
 bytes for single encryption.
 
-Version 2.06,
+Version 2.07,
 #COMMENT#
 
 (c) Peter J Billam 1998
